import os
import re

import apport.packaging
import apport.hookutils

def mask_string (str):
    MASK = '##MASKED##'
    return str.group(1) + MASK

def mask_values(gconfinfo):
    """ strip personal/private information from the GConf entries """
    pattrn = re.compile ('((add_dir|library_locations|download_prefix|share_password|share_name|username|password)=)(.*)$',
    re.IGNORECASE)
    newReport = ""
    for line in gconfinfo.splitlines():
        line = pattrn.sub (mask_string, line)
        newReport += line + '\n'
    return newReport

def add_info(report, ui):

    # Check to see if the stacktrace is a webkit or libubuntuone issue
    # if it is, then reassign to the Ubuntu One Music Store
    stacktrace = report.get("Stacktrace", None)
    if stacktrace and ("ubuntuone" in stacktrace or "webkit" in stacktrace):
        try:
            if apport.packaging.get_version("rhythmbox-ubuntuone"):
                report.add_package_info("rhythmbox-ubuntuone")
                return
        except ValueError:
            # RB-UbuntuOne not installed, must be our problem after all
            pass

    response = ui.choice("How would you describe the issue?", [
            "problem with the interface",
            "problem with sound",
            "problem with playback of audio files",
            "problem with Ubuntu One Music Store",
            "other problem",
            ], False)

    if response == None: # user cancelled
        raise StopIteration
# TODO: port to gsettings
#    if response[0] == 0: # an issue about rhythmbox interface
#        apport.hookutils.attach_gconf(report, 'rhythmbox')
#        report['GConfNonDefault'] = mask_values(report['GConfNonDefault'])
    if response[0] == 1: # the issue is a sound one
        os.execlp('apport-bug', 'apport-bug', 'audio')
    if response[0] == 2: # the issue is a codec one
        report.add_package_info("libgstreamer1.0-0")
        return
    if response[0] == 3: # problem with the music store
        report.add_package_info("rhythmbox-ubuntuone")
        return

    report["LogAlsaMixer"] = apport.hookutils.command_output(["/usr/bin/amixer"])
    report["GstreamerVersions"] = apport.hookutils.package_versions("gstreamer*")
    report["XorgLog"] = apport.hookutils.read_file("/var/log/Xorg.0.log")
